@@ -32,16 +32,20 @@ if [ `hal-get-property --udi /org/freedesktop/Hal/devices/platform_kb_lock --key
 		rm /tmp/savepress
 	
 		# restore settings
-		if [ "`cat /tmp/savepress-value | grep "offline"`" == "offline" ]; then {
+		if [ "`cat /tmp/savepress-value | grep "offline"`" != "" ]; then {
 			dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:"normal"
 			}
 		fi
+		if [ "`cat /tmp/savepress-value | grep "wlan-dis"`" != "" ]; then {
+			dbus-send --system --type=method_call --dest=com.nokia.icd /com/nokia/icd com.nokia.icd.connect string:"[ANY]" uint32:0
+			}
+		fi
 		if [ "`cat /tmp/savepress-value | grep "mode" | sed 's/mode: //g'`" != "" ]; then {
 			dbus-send --system --type=method_call --dest=com.nokia.phone.net /com/nokia/phone/net Phone.Net.set_selected_radio_access_technology byte:"`cat /tmp/savepress-value | grep "mode" | sed 's/mode: //g'`"
 			}
 		fi
 		run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"savepress is disabled!"
-		rm /tmp/savepress-value
+		rm -y /tmp/savepress-value
 		}
 	else {
 		echo "activating.."
@@ -52,8 +56,10 @@ if [ `hal-get-property --udi /org/freedesktop/Hal/devices/platform_kb_lock --key
 		echo "`/usr/sbin/kernel-config show | grep "max" | sed 's/. frequency//g'`" > /tmp/savepress-value
 		echo "`/usr/sbin/kernel-config show | grep "min" | sed 's/. frequency//g'`" >> /tmp/savepress-value
 		if [ "`cat /home/user/.config/savepress | grep "vwlan" | sed 's/vwlan: //g' | sed 's/ //g'`" == "True" ]; then {
-			if [ "`/sbin/ifconfig wlan0 | grep "inet addr" | awk -F: '{print $2}' | awk '{print $1}'`" != "" ]; then {
+			ip="`/sbin/ifconfig wlan0 | grep "inet addr" | awk -F: '{print $2}' | awk '{print $1}'`"
+			if [ "$ip" != "" ]; then {
 				dbus-send --system --dest=com.nokia.icd /com/nokia/icd_ui com.nokia.icd_ui.disconnect boolean:true
+				echo "wlan-dis" >> /tmp/savepress-value
 				}
 			fi
 			}
@@ -65,11 +71,11 @@ if [ `hal-get-property --udi /org/freedesktop/Hal/devices/platform_kb_lock --key
 		fi
 
 		if [ "`cat /home/user/.config/savepress | grep "voffline" | sed 's/voffline: //g' | sed 's/ //g'`" == "True" ]; then {
-#			if [ "`dbus-send --print-reply --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.get_device_mode | grep -q normal`" == "normal" ]; then {
+			if [ "`dbus-send --print-reply --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.get_device_mode | grep -o normal`" == "normal" ]; then {
 				dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:"offline"
 				echo "offline" >> /tmp/savepress-value
-#				}
-#			fi
+				}
+			fi
 			}
 		else {
 			if [ "`cat /home/user/.config/savepress | grep "v2g" | sed 's/v2g: //g' | sed 's/ //g'`" == "True" ]; then {
